@@ -86,7 +86,7 @@
 #define KSYNTAXHIGHLIGHTING_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KSYNTAXHIGHLIGHTING_NO_DEPRECATED
-#  define KSYNTAXHIGHLIGHTING_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KSYNTAXHIGHLIGHTING_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KSYNTAXHIGHLIGHTING_NO_DEPRECATED_WARNINGS
 #  define KSYNTAXHIGHLIGHTING_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KSYNTAXHIGHLIGHTING_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KSYNTAXHIGHLIGHTING_DEPRECATED_WARNINGS_SINCE KSYNTAXHIGHLIGHTING_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KSYNTAXHIGHLIGHTING_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KSYNTAXHIGHLIGHTING_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -180,7 +180,7 @@
 #define KSYNTAXHIGHLIGHTING_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KSYNTAXHIGHLIGHTING_NO_DEPRECATED
-#  define KSYNTAXHIGHLIGHTING_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KSYNTAXHIGHLIGHTING_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KSYNTAXHIGHLIGHTING_NO_DEPRECATED_WARNINGS
 #  define KSYNTAXHIGHLIGHTING_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +190,7 @@
 #  ifdef KSYNTAXHIGHLIGHTING_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KSYNTAXHIGHLIGHTING_DEPRECATED_WARNINGS_SINCE KSYNTAXHIGHLIGHTING_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KSYNTAXHIGHLIGHTING_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KSYNTAXHIGHLIGHTING_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
